PCB Environment: py::NPArray< T > Class Template Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions
py::NPArray< T > Class Template Reference

## Public Member Functions
NPArray< T > & | operator= (const NPArray< T > &avoid)
NPArray< T > & | operator= (NPArray< T > &&move)
| NPArray (const NPArray< T > &avoid)
| NPArray (NPArray< T > &&move)
| NPArray (const std::vector< T > &)
| NPArray (const std::vector< T > &, npy_intp d1, npy_intp d2)
| NPArray (T *, npy_intp const *dims, uint num_dims)
| NPArray (T *, npy_intp d1)
| NPArray (T *, npy_intp d1, npy_intp d2)
| NPArray (T *, npy_intp d1, npy_intp d2, npy_intp d3)
| NPArray (T *, npy_intp d1, npy_intp d2, npy_intp d3, npy_intp d4)
| NPArray (PyObject *py)
bool | own (PyObject *)
bool | own (PyArrayObject *)
NPArray< T > & | ownData ()
bool | valid () const
bool | isPacked () const
void | Assert () const
PyObject * | release ()
PyObject * | py () const
PyArrayObject * | pyArray () const
T * | data () const
intptr_t | count () const
intptr_t | stride (uint d) const
intptr_t | size () const
uint | dim (uint d) const
uint | degree () const
T | operator() (uint x) const
T | operator() (uint x, uint y) const
T | operator() (uint x, uint y, uint z) const
T | operator() (uint x, uint y, uint z, uint i) const
void | copyto (std::vector< T > &) const
std::vector< T > | vector () const

## Static Public Member Functions
static NPArray< T > * | create (PyObject *)
static void | checkAPI ()
static bool | checkType (PyArrayObject *)
static int | classTypenum ()

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/PyArray.hpp